/*
  PDD layer implementation for peripheral type CRC
  (C) 2010 Freescale, Inc. All rights reserved.

  This file is static and it is generated from API-Factory
*/

#if !defined(CRC_PDD_H_)
#define CRC_PDD_H_

/* ----------------------------------------------------------------------------
   -- Test if supported MCU is active
   ---------------------------------------------------------------------------- */

#if !defined(MCU_ACTIVE)
  // No MCU is active
  #error CRC PDD library: No derivative is active. Place proper #include with PDD memory map before including PDD library.
#elif \
      !defined(MCU_MK10D10) /* CRC */ && \
      !defined(MCU_MK10D5) /* CRC */ && \
      !defined(MCU_MK10D7) /* CRC */ && \
      !defined(MCU_MK10F12) /* CRC */ && \
      !defined(MCU_MK10DZ10) /* CRC */ && \
      !defined(MCU_MK11D5) /* CRC */ && \
      !defined(MCU_MK12D5) /* CRC */ && \
      !defined(MCU_MK20D10) /* CRC */ && \
      !defined(MCU_MK20D5) /* CRC */ && \
      !defined(MCU_MK20D7) /* CRC */ && \
      !defined(MCU_MK20F12) /* CRC */ && \
      !defined(MCU_MK20DZ10) /* CRC */ && \
      !defined(MCU_MK21D5) /* CRC */ && \
      !defined(MCU_MK22D5) /* CRC */ && \
      !defined(MCU_MK30D10) /* CRC */ && \
      !defined(MCU_MK30D7) /* CRC */ && \
      !defined(MCU_MK30DZ10) /* CRC */ && \
      !defined(MCU_MK40D10) /* CRC */ && \
      !defined(MCU_MK40D7) /* CRC */ && \
      !defined(MCU_MK40DZ10) /* CRC */ && \
      !defined(MCU_MK40X256VMD100) /* CRC */ && \
      !defined(MCU_MK50D10) /* CRC */ && \
      !defined(MCU_MK50D7) /* CRC */ && \
      !defined(MCU_MK50DZ10) /* CRC */ && \
      !defined(MCU_MK51D10) /* CRC */ && \
      !defined(MCU_MK51D7) /* CRC */ && \
      !defined(MCU_MK51DZ10) /* CRC */ && \
      !defined(MCU_MK52D10) /* CRC */ && \
      !defined(MCU_MK52DZ10) /* CRC */ && \
      !defined(MCU_MK53D10) /* CRC */ && \
      !defined(MCU_MK53DZ10) /* CRC */ && \
      !defined(MCU_MK60D10) /* CRC */ && \
      !defined(MCU_MK60F12) /* CRC */ && \
      !defined(MCU_MK60F15) /* CRC */ && \
      !defined(MCU_MK60DZ10) /* CRC */ && \
      !defined(MCU_MK60N512VMD100) /* CRC */ && \
      !defined(MCU_MK61F12) /* CRC */ && \
      !defined(MCU_MK61F15) /* CRC */ && \
      !defined(MCU_MK70F12) /* CRC */ && \
      !defined(MCU_MK70F15) /* CRC */ && \
      !defined(MCU_PCK20L4) /* CRC */
  // Unsupported MCU is active
  #error CRC PDD library: Unsupported derivative is active.
#endif

#include "PDD_Types.h"

/* ----------------------------------------------------------------------------
   -- Method symbol definitions
   ---------------------------------------------------------------------------- */

/* Computation parameters of CRC standards. */
#define CRC_PDD_NO_TRANSPOSE 0U                  /**< No transpose of data. */
#define CRC_PDD_BITS 0x1U                        /**< Bits are swapped. */
#define CRC_PDD_BITS_AND_BYTES 0x2U              /**< Bytes and bits are swapped. */
#define CRC_PDD_BYTES 0x3U                       /**< Bytes are swapped. */


/* ----------------------------------------------------------------------------
   -- GetCRCDataRegister
   ---------------------------------------------------------------------------- */

#if ((defined(MCU_MK11D5)) || (defined(MCU_MK12D5)) || (defined(MCU_MK21D5)) || (defined(MCU_MK22D5)))
/**
 * Returns current CRC result from data register.
 * @param peripheralBase Peripheral base address.
 */
  #define CRC_PDD_GetCRCDataRegister(peripheralBase) ( \
      CRC_DATA_REG(peripheralBase) \
    )
#else /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */
/**
 * Returns current CRC result from data register.
 * @param peripheralBase Peripheral base address.
 */
  #define CRC_PDD_GetCRCDataRegister(peripheralBase) ( \
      CRC_CRC_REG(peripheralBase) \
    )
#endif /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */

/* ----------------------------------------------------------------------------
   -- GetCRCDataHRegister
   ---------------------------------------------------------------------------- */

#if ((defined(MCU_MK11D5)) || (defined(MCU_MK12D5)) || (defined(MCU_MK21D5)) || (defined(MCU_MK22D5)))
/**
 * Returns upper 16bits of current CRC result from data register.
 * @param peripheralBase Peripheral base address.
 */
  #define CRC_PDD_GetCRCDataHRegister(peripheralBase) ( \
      CRC_DATAH_REG(peripheralBase) \
    )
#else /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */
/**
 * Returns upper 16bits of current CRC result from data register.
 * @param peripheralBase Peripheral base address.
 */
  #define CRC_PDD_GetCRCDataHRegister(peripheralBase) ( \
      CRC_CRCH_REG(peripheralBase) \
    )
#endif /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */

/* ----------------------------------------------------------------------------
   -- GetCRCDataLRegister
   ---------------------------------------------------------------------------- */

#if ((defined(MCU_MK11D5)) || (defined(MCU_MK12D5)) || (defined(MCU_MK21D5)) || (defined(MCU_MK22D5)))
/**
 * Returns lower 16bits of current CRC result from data register.
 * @param peripheralBase Peripheral base address.
 */
  #define CRC_PDD_GetCRCDataLRegister(peripheralBase) ( \
      CRC_DATAL_REG(peripheralBase) \
    )
#else /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */
/**
 * Returns lower 16bits of current CRC result from data register.
 * @param peripheralBase Peripheral base address.
 */
  #define CRC_PDD_GetCRCDataLRegister(peripheralBase) ( \
      CRC_CRCL_REG(peripheralBase) \
    )
#endif /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */

/* ----------------------------------------------------------------------------
   -- SetCRCDataRegister
   ---------------------------------------------------------------------------- */

#if ((defined(MCU_MK11D5)) || (defined(MCU_MK12D5)) || (defined(MCU_MK21D5)) || (defined(MCU_MK22D5)))
/**
 * Set CRC data register (4 bytes).
 * @param peripheralBase Peripheral base address.
 * @param Data New data for CRC computation.
 */
  #define CRC_PDD_SetCRCDataRegister(peripheralBase, Data) ( \
      CRC_DATA_REG(peripheralBase) = \
       (uint32_t)(Data) \
    )
#else /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */
/**
 * Set CRC data register (4 bytes).
 * @param peripheralBase Peripheral base address.
 * @param Data New data for CRC computation.
 */
  #define CRC_PDD_SetCRCDataRegister(peripheralBase, Data) ( \
      CRC_CRC_REG(peripheralBase) = \
       (uint32_t)(Data) \
    )
#endif /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */

/* ----------------------------------------------------------------------------
   -- SetCRCDataLRegister
   ---------------------------------------------------------------------------- */

#if ((defined(MCU_MK11D5)) || (defined(MCU_MK12D5)) || (defined(MCU_MK21D5)) || (defined(MCU_MK22D5)))
/**
 * Set CRC data register (2 bytes).
 * @param peripheralBase Peripheral base address.
 * @param Data New data for CRC computation.
 */
  #define CRC_PDD_SetCRCDataLRegister(peripheralBase, Data) ( \
      CRC_DATAL_REG(peripheralBase) = \
       (uint16_t)(Data) \
    )
#else /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */
/**
 * Set CRC data register (2 bytes).
 * @param peripheralBase Peripheral base address.
 * @param Data New data for CRC computation.
 */
  #define CRC_PDD_SetCRCDataLRegister(peripheralBase, Data) ( \
      CRC_CRCL_REG(peripheralBase) = \
       (uint16_t)(Data) \
    )
#endif /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */

/* ----------------------------------------------------------------------------
   -- SetCRCDataLLRegister
   ---------------------------------------------------------------------------- */

#if ((defined(MCU_MK11D5)) || (defined(MCU_MK12D5)) || (defined(MCU_MK21D5)) || (defined(MCU_MK22D5)))
/**
 * Set CRC data register (1 byte).
 * @param peripheralBase Peripheral base address.
 * @param Data New data for CRC computation.
 */
  #define CRC_PDD_SetCRCDataLLRegister(peripheralBase, Data) ( \
      CRC_DATALL_REG(peripheralBase) = \
       (uint8_t)(Data) \
    )
#else /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */
/**
 * Set CRC data register (1 byte).
 * @param peripheralBase Peripheral base address.
 * @param Data New data for CRC computation.
 */
  #define CRC_PDD_SetCRCDataLLRegister(peripheralBase, Data) ( \
      CRC_CRCLL_REG(peripheralBase) = \
       (uint8_t)(Data) \
    )
#endif /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */

/* ----------------------------------------------------------------------------
   -- SetCRCControlRegister
   ---------------------------------------------------------------------------- */

/**
 * Set CRC control register.
 * @param peripheralBase Peripheral base address.
 * @param Data Control register value.
 */
#define CRC_PDD_SetCRCControlRegister(peripheralBase, Data) ( \
    CRC_CTRL_REG(peripheralBase) = \
     (uint32_t)(Data) \
  )

/* ----------------------------------------------------------------------------
   -- SetSeedBit
   ---------------------------------------------------------------------------- */

/**
 * Enable seed mode.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_SetSeedBit(peripheralBase) ( \
    CRC_CTRL_REG(peripheralBase) |= \
     CRC_CTRL_WAS_MASK \
  )

/* ----------------------------------------------------------------------------
   -- ClearSeedBit
   ---------------------------------------------------------------------------- */

/**
 * Disable seed mode.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_ClearSeedBit(peripheralBase) ( \
    CRC_CTRL_REG(peripheralBase) &= \
     (uint32_t)(~(uint32_t)CRC_CTRL_WAS_MASK) \
  )

/* ----------------------------------------------------------------------------
   -- SetXorBit
   ---------------------------------------------------------------------------- */

/**
 * Enable result XORing with 0xFFFF or 0xFFFFFFFF.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_SetXorBit(peripheralBase) ( \
    CRC_CTRL_REG(peripheralBase) |= \
     CRC_CTRL_FXOR_MASK \
  )

/* ----------------------------------------------------------------------------
   -- ClearXorBit
   ---------------------------------------------------------------------------- */

/**
 * Disable result XORing with 0xFFFF or 0xFFFFFFFF.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_ClearXorBit(peripheralBase) ( \
    CRC_CTRL_REG(peripheralBase) &= \
     (uint32_t)(~(uint32_t)CRC_CTRL_FXOR_MASK) \
  )

/* ----------------------------------------------------------------------------
   -- SetCRC32bit
   ---------------------------------------------------------------------------- */

/**
 * Set CRC module for 32bit computation.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_SetCRC32bit(peripheralBase) ( \
    CRC_CTRL_REG(peripheralBase) |= \
     CRC_CTRL_TCRC_MASK \
  )

/* ----------------------------------------------------------------------------
   -- SetCRC16bit
   ---------------------------------------------------------------------------- */

/**
 * Set CRC module for 16bit computation.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_SetCRC16bit(peripheralBase) ( \
    CRC_CTRL_REG(peripheralBase) &= \
     (uint32_t)(~(uint32_t)CRC_CTRL_TCRC_MASK) \
  )

/* ----------------------------------------------------------------------------
   -- SetInputTranspose
   ---------------------------------------------------------------------------- */

/**
 * Set input data transposition type.
 * @param peripheralBase Peripheral base address.
 * @param Type Input data transposition type.
 */
#define CRC_PDD_SetInputTranspose(peripheralBase, Type) ( \
    CRC_CTRL_REG(peripheralBase) = \
     (uint32_t)(( \
      (uint32_t)(CRC_CTRL_REG(peripheralBase) & (uint32_t)(~(uint32_t)CRC_CTRL_TOT_MASK))) | ( \
      (uint32_t)((uint32_t)(Type) << CRC_CTRL_TOT_SHIFT))) \
  )

/* ----------------------------------------------------------------------------
   -- SetOutputTranspose
   ---------------------------------------------------------------------------- */

/**
 * Set output data transposition type.
 * @param peripheralBase Peripheral base address.
 * @param Type Output data transposition type.
 */
#define CRC_PDD_SetOutputTranspose(peripheralBase, Type) ( \
    CRC_CTRL_REG(peripheralBase) = \
     (uint32_t)(( \
      (uint32_t)(CRC_CTRL_REG(peripheralBase) & (uint32_t)(~(uint32_t)CRC_CTRL_TOTR_MASK))) | ( \
      (uint32_t)((uint32_t)(Type) << CRC_CTRL_TOTR_SHIFT))) \
  )

/* ----------------------------------------------------------------------------
   -- GetOutputTranspose
   ---------------------------------------------------------------------------- */

/**
 * Get output transpose settings.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_GetOutputTranspose(peripheralBase) ( \
    (uint8_t)(( \
     (uint32_t)(CRC_CTRL_REG(peripheralBase) & CRC_CTRL_TOTR_MASK)) >> ( \
     CRC_CTRL_TOTR_SHIFT)) \
  )

/* ----------------------------------------------------------------------------
   -- GetInputTranspose
   ---------------------------------------------------------------------------- */

/**
 * Get input transpose settings.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_GetInputTranspose(peripheralBase) ( \
    (uint8_t)(( \
     (uint32_t)(CRC_CTRL_REG(peripheralBase) & CRC_CTRL_TOT_MASK)) >> ( \
     CRC_CTRL_TOT_SHIFT)) \
  )

/* ----------------------------------------------------------------------------
   -- SetPolyHigh
   ---------------------------------------------------------------------------- */

/**
 * Set upper 16 bits of polynomial register.
 * @param peripheralBase Peripheral base address.
 * @param Data Polynomial value.
 */
#define CRC_PDD_SetPolyHigh(peripheralBase, Data) ( \
    CRC_GPOLYH_REG(peripheralBase) = \
     (uint16_t)(Data) \
  )

/* ----------------------------------------------------------------------------
   -- SetPolyLow
   ---------------------------------------------------------------------------- */

/**
 * Set lower 16 bits of polynomial register.
 * @param peripheralBase Peripheral base address.
 * @param Data Polynomial value.
 */
#define CRC_PDD_SetPolyLow(peripheralBase, Data) ( \
    CRC_GPOLYL_REG(peripheralBase) = \
     (uint16_t)(Data) \
  )

/* ----------------------------------------------------------------------------
   -- SetSeedHigh
   ---------------------------------------------------------------------------- */

#if ((defined(MCU_MK11D5)) || (defined(MCU_MK12D5)) || (defined(MCU_MK21D5)) || (defined(MCU_MK22D5)))
/**
 * Set upper 16 bits of data register in seed mode.
 * @param peripheralBase Peripheral base address.
 * @param Data Seed value.
 */
  #define CRC_PDD_SetSeedHigh(peripheralBase, Data) ( \
      CRC_DATAH_REG(peripheralBase) = \
       (uint16_t)(Data) \
    )
#else /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */
/**
 * Set upper 16 bits of data register in seed mode.
 * @param peripheralBase Peripheral base address.
 * @param Data Seed value.
 */
  #define CRC_PDD_SetSeedHigh(peripheralBase, Data) ( \
      CRC_CRCH_REG(peripheralBase) = \
       (uint16_t)(Data) \
    )
#endif /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */

/* ----------------------------------------------------------------------------
   -- SetSeedLow
   ---------------------------------------------------------------------------- */

#if ((defined(MCU_MK11D5)) || (defined(MCU_MK12D5)) || (defined(MCU_MK21D5)) || (defined(MCU_MK22D5)))
/**
 * Set lower 16 bits of data register in seed mode.
 * @param peripheralBase Peripheral base address.
 * @param Data Seed value.
 */
  #define CRC_PDD_SetSeedLow(peripheralBase, Data) ( \
      CRC_DATAL_REG(peripheralBase) = \
       (uint16_t)(Data) \
    )
#else /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */
/**
 * Set lower 16 bits of data register in seed mode.
 * @param peripheralBase Peripheral base address.
 * @param Data Seed value.
 */
  #define CRC_PDD_SetSeedLow(peripheralBase, Data) ( \
      CRC_CRCL_REG(peripheralBase) = \
       (uint16_t)(Data) \
    )
#endif /* (defined(MCU_MK10D10)) || (defined(MCU_MK10D5)) || (defined(MCU_MK10D7)) || (defined(MCU_MK10DZ10)) || (defined(MCU_MK10F12)) || (defined(MCU_MK20D10)) || (defined(MCU_MK20D5)) || (defined(MCU_MK20D7)) || (defined(MCU_MK20DZ10)) || (defined(MCU_MK20F12)) || (defined(MCU_MK30D10)) || (defined(MCU_MK30D7)) || (defined(MCU_MK30DZ10)) || (defined(MCU_MK40D10)) || (defined(MCU_MK40D7)) || (defined(MCU_MK40DZ10)) || (defined(MCU_MK40X256VMD100)) || (defined(MCU_MK50D10)) || (defined(MCU_MK50D7)) || (defined(MCU_MK50DZ10)) || (defined(MCU_MK51D10)) || (defined(MCU_MK51D7)) || (defined(MCU_MK51DZ10)) || (defined(MCU_MK52D10)) || (defined(MCU_MK52DZ10)) || (defined(MCU_MK53D10)) || (defined(MCU_MK53DZ10)) || (defined(MCU_MK60D10)) || (defined(MCU_MK60DZ10)) || (defined(MCU_MK60F12)) || (defined(MCU_MK60F15)) || (defined(MCU_MK60N512VMD100)) || (defined(MCU_MK61F12)) || (defined(MCU_MK61F15)) || (defined(MCU_MK70F12)) || (defined(MCU_MK70F15)) || (defined(MCU_PCK20L4)) */

/* ----------------------------------------------------------------------------
   -- SetCRC_16
   ---------------------------------------------------------------------------- */

/**
 * Set control register for CRC16 standard operation and starts seed mode.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_SetCRC_16(peripheralBase) ( \
    CRC_CTRL_REG(peripheralBase) = \
     (uint32_t)(( \
      (uint32_t)(( \
       CRC_CTRL_REG(peripheralBase)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TCRC_MASK)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_FXOR_MASK)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TOT_MASK)) & ( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TOTR_MASK))))))) | (( \
      CRC_CTRL_WAS_MASK) | (( \
      (uint32_t)((uint32_t)0x1U << CRC_CTRL_TOT_SHIFT)) | ( \
      (uint32_t)((uint32_t)0x2U << CRC_CTRL_TOTR_SHIFT))))) \
  )

/* ----------------------------------------------------------------------------
   -- SetCRC_32
   ---------------------------------------------------------------------------- */

/**
 * Set control register for CRC32 standard operation and starts seed mode.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_SetCRC_32(peripheralBase) ( \
    CRC_CTRL_REG(peripheralBase) = \
     (uint32_t)(( \
      (uint32_t)(( \
       (uint32_t)(( \
        CRC_CTRL_REG(peripheralBase)) | (( \
        CRC_CTRL_TCRC_MASK) | (( \
        CRC_CTRL_WAS_MASK) | ( \
        CRC_CTRL_FXOR_MASK))))) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TOT_MASK)) & ( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TOTR_MASK))))) | (( \
      (uint32_t)((uint32_t)0x1U << CRC_CTRL_TOT_SHIFT)) | ( \
      (uint32_t)((uint32_t)0x2U << CRC_CTRL_TOTR_SHIFT)))) \
  )

/* ----------------------------------------------------------------------------
   -- SetCRC_CCITT
   ---------------------------------------------------------------------------- */

/**
 * Set control register for CCITT standard operation and starts seed mode.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_SetCRC_CCITT(peripheralBase) ( \
    CRC_CTRL_REG(peripheralBase) = \
     (uint32_t)(( \
      (uint32_t)(( \
       CRC_CTRL_REG(peripheralBase)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TCRC_MASK)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_FXOR_MASK)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TOT_MASK)) & ( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TOTR_MASK))))))) | ( \
      CRC_CTRL_WAS_MASK)) \
  )

/* ----------------------------------------------------------------------------
   -- SetCRC_KERMIT
   ---------------------------------------------------------------------------- */

/**
 * Set control register for KERMIT standard operation and starts seed mode.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_SetCRC_KERMIT(peripheralBase) ( \
    CRC_CTRL_REG(peripheralBase) = \
     (uint32_t)(( \
      (uint32_t)(( \
       CRC_CTRL_REG(peripheralBase)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TCRC_MASK)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_FXOR_MASK)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TOT_MASK)) & ( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TOTR_MASK))))))) | (( \
      CRC_CTRL_WAS_MASK) | (( \
      (uint32_t)((uint32_t)0x1U << CRC_CTRL_TOT_SHIFT)) | ( \
      (uint32_t)((uint32_t)0x2U << CRC_CTRL_TOTR_SHIFT))))) \
  )

/* ----------------------------------------------------------------------------
   -- SetCRC_DNP
   ---------------------------------------------------------------------------- */

/**
 * Set control register for DNP standard operation and starts seed mode.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_SetCRC_DNP(peripheralBase) ( \
    CRC_CTRL_REG(peripheralBase) = \
     (uint32_t)(( \
      (uint32_t)(( \
       CRC_CTRL_REG(peripheralBase)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TCRC_MASK)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TOT_MASK)) & ( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TOTR_MASK)))))) | (( \
      CRC_CTRL_WAS_MASK) | (( \
      CRC_CTRL_FXOR_MASK) | (( \
      (uint32_t)((uint32_t)0x1U << CRC_CTRL_TOT_SHIFT)) | ( \
      (uint32_t)((uint32_t)0x2U << CRC_CTRL_TOTR_SHIFT)))))) \
  )

/* ----------------------------------------------------------------------------
   -- SetCRC_MODBUS16
   ---------------------------------------------------------------------------- */

/**
 * Set control register for MODBUS16 standard operation and starts seed mode.
 * @param peripheralBase Peripheral base address.
 */
#define CRC_PDD_SetCRC_MODBUS16(peripheralBase) ( \
    CRC_CTRL_REG(peripheralBase) = \
     (uint32_t)(( \
      (uint32_t)(( \
       CRC_CTRL_REG(peripheralBase)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TCRC_MASK)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_FXOR_MASK)) & (( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TOT_MASK)) & ( \
       (uint32_t)(~(uint32_t)CRC_CTRL_TOTR_MASK))))))) | (( \
      CRC_CTRL_WAS_MASK) | (( \
      (uint32_t)((uint32_t)0x1U << CRC_CTRL_TOT_SHIFT)) | ( \
      (uint32_t)((uint32_t)0x2U << CRC_CTRL_TOTR_SHIFT))))) \
  )
#endif  /* #if defined(CRC_PDD_H_) */

/* CRC_PDD.h, eof. */
