/** ###################################################################
**     Filename    : ProcessorExpert.c
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Version     : Driver 01.01
**     Compiler    : GNU C Compiler
**     Date/Time   : 2012-08-02, 10:36, # CodeGen: 0
**     Abstract    :
**         Main module.
**         This module contains user's application code.
**     Settings    :
**     Contents    :
**         No public methods
**
** ###################################################################*/
/* MODULE ProcessorExpert */


/* Including needed modules to compile this module/procedure */
#include "Cpu.h"
#include "Events.h"
#include "ADC0.h"
#include "GPIO1.h"
#include "TPM0.h"
#include "DMAT_Mem.h"
#include "DMAT_UART_OUT.h"
#include "LPTmr1.h"
#include "GPIO2_VDD.h"
#include "GPIO3_VSS.h"
#include "DMAT_ADC.h"
#include "DMA1.h"
/* Including shared modules, which are used for whole project */
#include "PE_Types.h"
#include "PE_Error.h"
#include "PE_Const.h"
#include "IO_Map.h"

/* User includes (#include below this line is not maintained by Processor Expert) */
#include <stdlib.h>
#include <stdio.h>

/** Global Variables **/
uint16 adc_val = 0;
uint8  conv_done = 0;
uint8  dma_done = 0;

#pragma location = "BUF_region"
uint16 MyStaticArray[32]={0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
char MyOutputArray[OUTPUT_ARRAY_SIZE] = {'0','x',0,0,0,0,'\n','\r'};

/////////////////////////////////////////////////////////////////////////////////
// Program Constant Definitions
#define TERMINAL_BAUD   19200
#define UART_IRCLK_SRC  3
#define ADC_ARRAYLOC    0x20002FC0

int main(void)
{
  /* Write your local variable definition here */
  uint8 i, temp8;
  uint32 myadcAvg = 0;
  uint16 *adcarray = (uint16 *)ADC_ARRAYLOC;
  uint32 temp32, uart0_clk_khz = 0;
  char tempchar = ' ';
  LDD_TError ErrVal = 0, StartErr = 0, CalErr = 0;
  
  LDD_DMA_TTransferDescriptor  UART_DMA_Descriptor;
  LDD_DMA_TTransferDescriptorPtr *UART_DMA_DescriptorPtr;
  
  UART_DMA_DescriptorPtr = (LDD_DMA_TTransferDescriptorPtr *)&UART_DMA_Descriptor;
  
  //LDD_TData *adc_buf[1];   // Use this when using CodeWarrior
  LDD_ADC_TSample *adc_buf; // Use this when using IAR

  /*** Processor Expert internal initialization. DON'T REMOVE THIS CODE!!! ***/
  PE_low_level_init();
  /*** End of Processor Expert internal initialization.                    ***/
  
  // Configure FCRDIV in the MCG to run the FIRC at 1 MHz
  temp8 = MCG_SC;
  temp8 &= ~MCG_SC_FCRDIV_MASK;
  temp8 |= MCG_SC_FCRDIV(2);
  MCG_SC = temp8;
  
  init_adcAvg_mem(adcarray);
  ////////////////////////////////////////////////////////////////////////////////
  // Configure UART0 
  
  // Configure UART pins
  // Enable the UART_TXD function on PTA1 
  PORTA_PCR1 = PORT_PCR_MUX(0x2);
          
  // Enable the UART_TXD function on PTA2 
  PORTA_PCR2 = PORT_PCR_MUX(0x2);
  
  // Configure UART0 clock source
  SIM_SOPT2 |= SIM_SOPT2_UART0SRC(UART_IRCLK_SRC);
  uart0_clk_khz = 1000;  // UART0 Clk in kHz = 1000 kHz if using the IRCLK at 1MHz
  
  // Initialize UART Module
  uart0_init (UART0_BASE_PTR, uart0_clk_khz, TERMINAL_BAUD);
 
  /*
  // A Sample group MUST be created or the ADC will not get samples!! */
  //StartErr = ADC0_CreateSampleGroup(ADC0_DeviceData, adc_buf, (uint8_t) 1);  // This causes the ChannelID issue in IAR as well.  
  StartErr = ADC0_SelectSampleGroup(ADC0_DeviceData, (uint8_t) 0);
  if (StartErr == ERR_OK)
    {}
    else
    {
  	  while(1)
  	  {}
    }
  
  // Toggle the status LED as the calibration is complete.  
   GPIO1_ToggleFieldBits(GPIO1_DeviceData, LED_BLUE, (GPIO1_TFieldValue)1);
   
  // Allocate and enable DMA channel for ADC transfers
   StartErr = DMAT_ADC_AllocateChannel(DMAT_ADC_DeviceData);
   
   StartErr = DMAT_ADC_EnableChannel(DMAT_ADC_DeviceData);
  
   // Allocate and enable DMA channel for Linked transfers to memory
   StartErr = DMAT_Mem_AllocateChannel(DMAT_Mem_DeviceData);
   
   StartErr = DMAT_Mem_EnableChannel(DMAT_Mem_DeviceData);
   
   // Allocate DMA channel for UART0 Transfers
   StartErr = DMAT_UART_OUT_AllocateChannel(DMAT_UART_OUT_DeviceData);
   
  // Start Measurements

   StartErr = ADC0_StartLoopTriggeredMeasurement(ADC0_DeviceData);
   
   ADC0_SC2 |= ADC_SC2_DMAEN_MASK;
   // Enable Global Interrupts
   Cpu_EnableInt();
   // Enable the Timer
   LPTMR0_CSR |= LPTMR_CSR_TEN_MASK;                   // Use this line if using the Init module
   
   // Setup to move to VLPS mode here.  The code should be configured to return to VLPS after ISR
   temp8 = SMC_PMCTRL;
   temp8 &= ~SMC_PMCTRL_STOPM_MASK;
   temp8 |= SMC_PMCTRL_STOPM(2);
   SMC_PMCTRL = temp8;
   
   // Execute dummy read
   temp8 = SMC_PMCTRL;
   
   // Set Deep Sleep bit
   SCB_SCR |= SCB_SCR_SLEEPDEEP_MASK;
   
   // Execute wait for interrupt command
   //asm("WFI");
   
   StartErr = DMAT_UART_OUT_EnableChannel(DMAT_UART_OUT_DeviceData);
   DMAMUX0_CHCFG2 = 0x83;
   
    while(1)
    {
        // Initialize the ADC average variable
        myadcAvg = 0;
        
    	 // Execute wait for interrupt command
    	 //asm("WFI");
        
        while(dma_done == 0);
         
        StartErr = DMAT_UART_OUT_DisableChannel(DMAT_UART_OUT_DeviceData);
        //DMAMUX0_CHCFG2 = 0x00;
        
        // Clear pending errors or the done bit 
	/*if (((DMA_DSR_BCR2 & DMA_DSR_BCR_DONE_MASK) == DMA_DSR_BCR_DONE_MASK)
	     | ((DMA_DSR_BCR2 & DMA_DSR_BCR_BES_MASK) == DMA_DSR_BCR_BES_MASK)
	     | ((DMA_DSR_BCR2 & DMA_DSR_BCR_BED_MASK) == DMA_DSR_BCR_BED_MASK)
	     | ((DMA_DSR_BCR2 & DMA_DSR_BCR_CE_MASK) == DMA_DSR_BCR_CE_MASK))
	{
	  DMA_DSR_BCR2 |= DMA_DSR_BCR_DONE_MASK;
	}
        */
        // Set the Byte Count for the UART0 DMA Transfer
        //StartErr = DMAT_UART_OUT_SetDescriptorUpdate(DMAT_UART_OUT_DeviceData, &UART_DMA_Descriptor);
        // Allocate and enable DMA channel for Linked transfers
        StartErr = DMAT_UART_OUT_AllocateChannel(DMAT_UART_OUT_DeviceData);
        
         for (i = 0; i < 32; i++)
         {
             //myadcAvg = myadcAvg + MyStaticArray[i];
	     myadcAvg = myadcAvg + *adcarray;
             adcarray++;
	 }
         adcarray = (uint16 *)ADC_ARRAYLOC;
         
         dma_done = 0;  // Signal that we are waiting on DMA again!
         
         // Total sum has been calculated, now calculate average
         myadcAvg = myadcAvg / 32;
         
         // 
         MyOutputArray[2] = itoa((myadcAvg & 0xF000 )>> 12);
         MyOutputArray[3] = itoa((myadcAvg & 0x0F00 )>> 8);
         MyOutputArray[4] = itoa((myadcAvg & 0xF0 )>> 4);
         MyOutputArray[5] = itoa((myadcAvg & 0xF ));
         
         // Clear Error or Done Bit
         if (((DMA_DSR_BCR2 & DMA_DSR_BCR_DONE_MASK) == DMA_DSR_BCR_DONE_MASK)
	     | ((DMA_DSR_BCR2 & DMA_DSR_BCR_BES_MASK) == DMA_DSR_BCR_BES_MASK)
	     | ((DMA_DSR_BCR2 & DMA_DSR_BCR_BED_MASK) == DMA_DSR_BCR_BED_MASK)
	     | ((DMA_DSR_BCR2 & DMA_DSR_BCR_CE_MASK) == DMA_DSR_BCR_CE_MASK))
         {
             DMA_DSR_BCR2 |= DMA_DSR_BCR_DONE_MASK;
         }
         
         StartErr = DMAT_UART_OUT_SetSourceAddress(DMAT_UART_OUT_DeviceData, (uint32_t)&MyOutputArray);
         StartErr = DMAT_UART_OUT_SetByteCount(DMAT_UART_OUT_DeviceData, (LDD_DMA_TByteCount)OUTPUT_ARRAY_SIZE);
         
         StartErr = DMAT_UART_OUT_EnableChannel(DMAT_UART_OUT_DeviceData);
         // Due to an error with Processor Expert, we have to write the channel number manually
         // We need to trigger the DMA transfers from UART0 TX. But PE would not let me generate
         // code for this.  Therefore, I selected UART1 TX as the trigger source.  So, we need to
         // write 0x83 (instead of 0x84) to the DMA Mux for Channel 2.
         //DMA_DSR_BCR2 |= DMA_DSR_BCR_BCR(0x8);  // The value written to the BCR must be WORD aligned!!!
         //DMA_DCR2 |= DMA_DCR_ERQ_MASK;
        //DMAMUX0_CHCFG2 = 0x83;
         //StartErr = DMAT_UART_OUT_StartTransfer(DMAT_UART_OUT_DeviceData);
         
         
    	// Old code used when not using the DMA to trigger the transfers from ADC result register
    	//   to the TPM registers. 
    	/*while (conv_done == 0)
    	{}
     	ErrVal = ADC0_GetMeasuredValues(ADC0_DeviceData, adc_buf);
        conv_done = 0;
             if (ErrVal == ERR_OK)
            {
                adc_val = (uint16)adc_buf[0];
                TPM2_C0V = adc_val/3;               
            }
            else
            {
                while(1);
            }
        //}*/
    }

  /*** Don't write any code pass this line, or it will be deleted during code generation. ***/
  /*** RTOS startup code. Macro PEX_RTOS_START is defined by the RTOS component. DON'T MODIFY THIS CODE!!! ***/
  #ifdef PEX_RTOS_START
    PEX_RTOS_START();                  /* Startup of the selected RTOS. Macro is defined by the RTOS component. */
  #endif
  /*** End of RTOS startup code.  ***/
  /*** Processor Expert end of main routine. DON'T MODIFY THIS CODE!!! ***/
  for(;;){}
  /*** Processor Expert end of main routine. DON'T WRITE CODE BELOW!!! ***/
  return 0;
} /*** End of main routine. DO NOT MODIFY THIS TEXT!!! ***/

/* END ProcessorExpert */
/*
** ###################################################################
**
**     This file was created by Processor Expert 10.0 [05.02]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
