/** ###################################################################
**     Filename    : Events.c
**     Project     : ProcessorExpert
**     Processor   : MKL25Z128VLK4
**     Component   : Events
**     Version     : Driver 01.00
**     Compiler    : GNU C Compiler
**     Date/Time   : 2012-08-08, 16:59, # CodeGen: 0
**     Abstract    :
**         This is user's event module.
**         Put your event handler code here.
**     Settings    :
**     Contents    :
**         Cpu_OnNMIINT - void Cpu_OnNMIINT(void);
**
** ###################################################################*/
/* MODULE Events */

#include "Cpu.h"
#include "Events.h"

/* User includes (#include below this line is not maintained by Processor Expert) */

/* Global Variables */
#define DATA_SIZE 13
extern volatile bool SlaveReceivedFlg;
extern volatile bool MasterReceivedFlg;
extern char master_receive[16];
extern char slave_receive[16];
extern char master_send[16];
extern char slave_send[16];

/*
** ===================================================================
**     Event       :  Cpu_OnNMIINT (module Events)
**
**     Component   :  Cpu [MKL25Z128LK4]
**     Description :
**         This event is called when the Non maskable interrupt had
**         occurred. This event is automatically enabled when the <NMI
**         interrrupt> property is set to 'Enabled'.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void Cpu_OnNMIINT(void)
{
  /* Write your code here ... */
}

/*
** ===================================================================
**     Event       :  Cpu_OnHardFault (module Events)
**
**     Component   :  Cpu [MKL25Z128LK4]
**     Description :
**         This event is called when the Hard Fault exception had
**         occurred. This event is automatically enabled when the <Hard
**         Fault> property is set to 'Enabled'.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void Cpu_OnHardFault(void)
{
  /* Write your code here ... */
}


void TERMINAL_OnBlockReceived(LDD_TUserData *UserDataPtr)
{
  /* Write your code here ... */
}

/*
** ===================================================================
**     Event       :  IO1_OnBlockReceived (module Events)
**
**     Component   :  IO1 [Serial_LDD]
**     Description :
**         This event is called when the requested number of data is
**         moved to the input buffer.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. This pointer is passed
**                           as the parameter of Init method.
**     Returns     : Nothing
** ===================================================================
*/
void IO1_OnBlockReceived(LDD_TUserData *UserDataPtr)
{
  /* Write your code here ... */
}

/*
** ===================================================================
**     Event       :  IO1_OnBlockSent (module Events)
**
**     Component   :  IO1 [Serial_LDD]
**     Description :
**         This event is called after the last character from the
**         output buffer is moved to the transmitter. 
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. This pointer is passed
**                           as the parameter of Init method.
**     Returns     : Nothing
** ===================================================================
*/
void IO1_OnBlockSent(LDD_TUserData *UserDataPtr)
{
  /* Write your code here ... */
}

/*
** ===================================================================
**     Event       :  SPI_S1_OnBlockSent (module Events)
**
**     Component   :  SPI_S1 [SPISlave_LDD]
**     Description :
**         This event is called after the last character from the
**         output buffer is moved to the transmitter. This event is
**         available only if the SendBlock method is enabled.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. The pointer is passed
**                           as the parameter of Init method. 
**     Returns     : Nothing
** ===================================================================
*/
void SPI_S1_OnBlockSent(LDD_TUserData *UserDataPtr)
{
  /* Write your code here ... */
}

/*
** ===================================================================
**     Event       :  SPI_S1_OnBlockReceived (module Events)
**
**     Component   :  SPI_S1 [SPISlave_LDD]
**     Description :
**         This event is called when the requested number of data is
**         moved to the input buffer. This method is available only if
**         the ReceiveBlock method is enabled.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. The pointer is passed
**                           as the parameter of Init method. 
**     Returns     : Nothing
** ===================================================================
*/
void SPI_S1_OnBlockReceived(LDD_TUserData *UserDataPtr)
{
  /* Write your code here ... */
	
	SlaveReceivedFlg = TRUE;  /* Set MasterReceivedFlg flag */
  
  if ((strcmp(slave_receive, "Send_Message1") == 0))
    {
      strcpy(slave_send,"Received_msg1");
      printf("\nSlave: Message1 received...\n");
    }
  else  if ((strcmp(slave_receive, "Send_Message2") == 0))
  {
      strcpy(slave_send,"Received_msg2");
      printf("\nSlave: Message2 received...\n");
  }
   else  if ((strcmp(slave_receive, "" ) == 0))
   {
     strcpy(slave_send,"No_received.."); 
     printf("\nSlave: Nothing received...\n"); 
   }
   else  if ((strcmp(slave_receive, "Message_dummy") == 0))
      strcpy(slave_send,"Message_dummy");  
   else {
      strcpy(slave_send,"Msg_unknown..");
      printf("\nSlave: Unknown message...\n");
   }
  
  SPI_S1_SendBlock(SPI_S1_DeviceData, slave_send, DATA_SIZE);
  SPI_S1_ReceiveBlock(SPI_S1_DeviceData, slave_receive, DATA_SIZE); 
}

/*
** ===================================================================
**     Event       :  SPI_M1_OnBlockSent (module Events)
**
**     Component   :  SPI_M1 [SPIMaster_LDD]
**     Description :
**         This event is called after the last character from the
**         output buffer is moved to the transmitter. This event is
**         available only if the SendBlock method is enabled.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. The pointer is passed
**                           as the parameter of Init method. 
**     Returns     : Nothing
** ===================================================================
*/
void SPI_M1_OnBlockSent(LDD_TUserData *UserDataPtr)
{
  /* Write your code here ... */
}

/*
** ===================================================================
**     Event       :  SPI_M1_OnBlockReceived (module Events)
**
**     Component   :  SPI_M1 [SPIMaster_LDD]
**     Description :
**         This event is called when the requested number of data is
**         moved to the input buffer. This method is available only if
**         the ReceiveBlock method is enabled.
**     Parameters  :
**         NAME            - DESCRIPTION
**       * UserDataPtr     - Pointer to the user or
**                           RTOS specific data. The pointer is passed
**                           as the parameter of Init method. 
**     Returns     : Nothing
** ===================================================================
*/
void SPI_M1_OnBlockReceived(LDD_TUserData *UserDataPtr)
{
  /* Write your code here ... */
	
	MasterReceivedFlg = TRUE;  /* Set MasterReceivedFlg flag */
    
  if ((strcmp(master_receive, "Message_dummy") != 0))
  {
      if ((strcmp(master_receive, "Received_msg1") == 0))
      {
         printf("\nMaster: Slave accepted Message1...\n");
        /* BLUE LED ON */ 
         Blue_LED_ClrVal(Blue_LED_DeviceData);
         Green_LED_SetVal(Green_LED_DeviceData);
         Red_LED_SetVal(Red_LED_DeviceData);         
      }
    else  if ((strcmp(master_receive, "Received_msg2") == 0))
    {
        printf("\nMaster: Slave accepted Message2...\n");
       /* GREEN LED ON */        
       Blue_LED_SetVal(Blue_LED_DeviceData);
       Green_LED_ClrVal(Green_LED_DeviceData);
       Red_LED_SetVal(Red_LED_DeviceData);
    }
     else  if ((strcmp(master_receive, "No_received..") == 0))
     {
        printf("\nMaster: Slave is not receiving messages...\n");
       /* RED LED ON */        
       Blue_LED_SetVal(Blue_LED_DeviceData);
       Green_LED_SetVal(Green_LED_DeviceData);
       Red_LED_ClrVal(Red_LED_DeviceData); 
     }
     else  if ((strcmp(master_receive, "Msg_unknown..") == 0))
     {
        printf("\nMaster: Slave is receiving unknown messages...\n");
       /* YELLOW LED ON */        
       Blue_LED_SetVal(Blue_LED_DeviceData);
       Green_LED_ClrVal(Green_LED_DeviceData);
       Red_LED_ClrVal(Red_LED_DeviceData);  
     }
     else  if ((strcmp(master_receive, "" ) == 0))
     {
       printf("\nMaster: Slave is not responding...\n"); 
       /* CYAN LED ON */
       Blue_LED_ClrVal(Blue_LED_DeviceData);
       Green_LED_ClrVal(Green_LED_DeviceData);
       Red_LED_SetVal(Red_LED_DeviceData);
     }
     else 
        printf("\nMaster: Unknown message...\n");
  }
}

/* END Events */

/*
** ###################################################################
**
**     This file was created by Processor Expert 10.0 [05.02]
**     for the Freescale Kinetis series of microcontrollers.
**
** ###################################################################
*/
